@@ -286,7 +286,7 @@ class ImageRecognition(object):
                  saver, 
                  train_generator,
                  val_generator,
-                 best_loss,
+                 best_acc,
                  path_tosave_model='model/model1'):
         """[summary]
         
@@ -308,7 +308,7 @@ class ImageRecognition(object):
         self.val_loss = []
         self.train_acc = []
         self.val_acc = []
-        best_loss = best_loss
+        best_acc = best_acc
         
         for i in range(iteration):
             sign = "-"
@@ -350,8 +350,8 @@ class ImageRecognition(object):
             self.train_loss.append(t_loss)
             self.val_loss.append(loss)
                 
-            if best_loss > loss:
-                best_loss = loss
+            if best_acc < val_acc:
+                best_acc = val_acc
                 sign = "************* model saved"
                 saver.save(session, path_tosave_model)
         
